import {
  select,
  scaleLinear,
  scalePoint,
  extent,
  axisLeft,
  axisBottom,
  area,
  max,
  nest,
  scaleOrdinal,
  schemeCategory10
} from 'd3';

const svg = select('svg');

const w = +svg.attr('width');
const h = +svg.attr('height');

const render = data => {
   data.forEach(d => {
      // eslint-disable-next-line no-param-reassign
      d.value = +d.value;
    });

    const title = "Mock";

    const xValue = d => d.month;
    const xAxisLabel = "Month";

    const yValue = d => d.value;
    // const circleRadius = 6;
    const yAxisLabel = "Energy";

    const margin = { top: 60, right: 40, bottom: 88, left: 105 };
    const innerWidth = w - margin.left - margin.right;
    const innerHeight = h - margin.top - margin.bottom;

    const xScale = scalePoint()
      .domain(data.map(xValue))
      .range([0, innerWidth]);

    const yScale = scaleLinear()
      .domain([0,max(data,yValue)])
      .range([innerHeight, 0])
      .nice();

    const g = svg
      .append("g")
      .attr("transform", `translate(${margin.left},${margin.top})`);

    const xAxis = axisBottom(xScale)
      .tickSize(-innerHeight)
      .tickPadding(15);

    const yAxis = axisLeft(yScale)
      .tickSize(-innerWidth)
      .tickPadding(10);

    const yAxisG = g.append("g").call(yAxis);
    yAxisG.selectAll(".domain").remove();

    yAxisG
      .append("text")
      .attr("class", "axis-label")
      .attr("y", -60)
      .attr("x", -innerHeight / 2)
      .attr("fill", "black")
      .attr("transform", `rotate(-90)`)
      .attr("text-anchor", "middle")
      .text(yAxisLabel);

    const xAxisG = g
      .append("g")
      .call(xAxis)
      .attr("transform", `translate(0,${innerHeight})`);

    xAxisG.select(".domain").remove();

    xAxisG
      .append("text")
      .attr("class", "axis-label")
      .attr("y", 80)
      .attr("x", innerWidth / 2)
      .attr("fill", "black")
      .text(xAxisLabel);

    const lineGenerator = area()
      .x(d => xScale(xValue(d)))
    	.y0(innerHeight)
      .y1(d => yScale(yValue(d)));

  	const valueline = d3.line()
    	.x(d => xScale(xValue(d)))
    	.y(d => yScale(yValue(d)));
  
  		
  const nested = nest().key(d => d.site).entries(data)
  //console.log(nested);
   		// g.selectAll('.line-path').data(energyData).enter().append("path")
   		// .attr("class", "line-path")
   		// .attr("d", d=> lineGenerator(d.values));
  
    var ageNames = nested.map(item => item.key);
  
  console.log(ageNames);
  
var n = 1;
      
var color2 = scaleOrdinal(schemeCategory10);
  
var colorTest = ["#fff", "#000"]

var legendGroup = svg.append("g")
    .attr("transform", "translate("+(innerWidth-50)+",70)");

var legend = legendGroup.selectAll(".legend")
	.data(ageNames)
	.enter()
	.append("g")
	.attr('transform', function(d, i) { return "translate(" + 70*i + "," + 0 + ")"; })
	.attr("class","legend");
	
var rects = legend.append('rect')
	.attr("width",15)
	.attr("height",15)
	.attr("fill", function(d,i) { return colorTest[i]; });
	
var text = legend.append('text')
	.attr("x", 20)
	.attr("y",12)
	.text(function(d) { return d; })
  
    var color = d3.scaleOrdinal()
  .domain(["site-1", "site-2"])
  .range(["rgb(255,55,190,0.7)", "rgb(170,0,255,0.3)"]);
  
  	const z = color;
  

  
      g.append("text")
      .attr("class", "title")
      .attr("y", -10)
      .text(title);
  

    const source = g.selectAll(".area")
      .data(nested)
      .enter().append("g")
      .attr("class", function(d) { return `area ${d.key}`; })

  			source.append("path")
       .attr("d", function(d) { console.log(lineGenerator(d.values)); return lineGenerator(d.values); })
       .style("fill", function(d) { return z(d.key); });
  
      source.selectAll('.line')
      .data(nested)
      .enter()
      .append("path")
      .attr("class", "line")
  		.attr("stroke", d=> z(d.key))
  		.attr("stroke-width", "3")
      .attr("d", d => valueline(d.values));
  
  
  	const bgcolors = {"site-1":"rgba(238,204,255,0.4)", "site-2":'rgba(255,55,190,0.4)' }
    const defs = svg.append('defs');
  const bgGradient = svg
.select('defs')
  .selectAll('linearGradient')
  .data(nested)
  .enter()
.append('linearGradient')
.attr('id', d => d.key )
.attr("class", "temp")
.attr("x1", "0%")
.attr("y1", "0%")
.attr("x2", "0%")
.attr("y2", "100%")
.append('stop')
.attr('stop-color', d => bgcolors[d.key])
.attr('offset', '0%');
  
svg
.select('defs')
.selectAll('linearGradient')
  .selectAll('stop')
    .data([0,2])
  .enter()
.append('stop')
.attr('stop-color', 'rgba(255,255,255,0.4)')
.attr('offset', '80%');
  
 defs
 .selectAll('.value-line')
  .data(nested)
  .enter()
  .append('clipPath')
  .attr('id', d => d.key + 'clip')
  .append('path')
  .attr('d', d => lineGenerator(d.values))
  .attr('class', 'value-line');

const clipPath = g
 	.selectAll('.clip-path')
  .data(nested)
  .enter()
  .append('g')
  .attr('clip-path', d => `url(#${d.key + 'clip'})`)
  .append('rect')
  .attr('x', 0)
  .attr('y', 0)
  .attr('width', w)
  .attr('height', h)
  .style('fill', d => `url(#${d.key})`)
  .attr('class', 'clip-path');
}; 

  


    const energyData = [
      { month: "January", value: "20", site: "site-1" },
      { month: "February", value: "25", site: "site-1" },
      { month: "March", value: "30", site: "site-1" },
      { month: "April", value: "40", site: "site-1" },
      { month: "May", value: "50", site: "site-1" },
      { month: "June", value: "20", site: "site-1" },
      { month: "July", value: "15", site: "site-1" },
      { month: "August", value: "25", site: "site-1" },
      { month: "September", value: "20", site: "site-1" },
      { month: "October", value: "30", site: "site-1" },
      { month: "November", value: "40", site: "site-1" },
      { month: "December", value: "19", site: "site-1" },
      
      {month: "January", value: 15, site: "site-2"  },
      													{ month: "February", value: 20, site: "site-2"  },
      													{ month: "March", value: 40, site: "site-2"  },
      													{ month: "April", value: 20, site: "site-2"  },
      													{ month: "May", value: 30, site: "site-2"  },
      													{ month: "June", value: 45, site: "site-2"  },
      													{ month: "July", value: 15, site: "site-2"  },
      													{ month: "August", value: 15, site: "site-2"  },
      													{ month: "September", value: 10, site: "site-2"  },
      													{ month: "October", value: 20, site: "site-2"  },
      													{ month: "November", value: 30, site: "site-2"  },
      													{ month: "December", value: 15, site: "site-2"  }
                               
      
    ];
      
    render(energyData);
